@@ -14,7 +14,7 @@ use POE qw(Component::Client::Ident::Agent);
 use Carp;
 use vars qw($VERSION);
 
-$VERSION = '1.10';
+$VERSION = '1.12';
 
 sub spawn {
     my ( $package, $alias ) = splice @_, 0, 2;
@@ -129,6 +129,10 @@ sub _parse_arguments {
   return @returns;
 }
 
+'Who are you?';
+
+__END__
+
 =head1 NAME
 
 POE::Component::Client::Ident - A component that provides non-blocking ident lookups to your sessions.
