@@ -15,7 +15,7 @@ use Carp;
 use Socket;
 use vars qw($VERSION);
 
-$VERSION = '1.10';
+$VERSION = '1.12';
 
 sub spawn {
     my $package = shift;
@@ -207,6 +207,10 @@ sub _parse_arguments {
   return @returns;
 }
 
+'Who are you?';
+
+__END__
+
 =head1 NAME
 
 POE::Component::Client::Ident::Agent - A component to provide a one-shot non-blocking Ident query.
